#
# spec file for package python-mistralclient
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-mistralclient
Version:        3.3.0
Release:        lp152.3.3
Summary:        Python API and CLI for OpenStack Mistral
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://launchpad.net/%{name}
Source0:        https://files.pythonhosted.org/packages/source/p/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-PyYAML >= 3.10
BuildRequires:  python-devel
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-mock >= 2.0.0
BuildRequires:  python-nose >= 1.3.7
BuildRequires:  python-openstackclient >= 3.12.0
BuildRequires:  python-oslotest >= 3.2.0
BuildRequires:  python-osprofiler >= 1.4.0
BuildRequires:  python-pbr >= 2.0.0
BuildRequires:  python-requests-mock >= 1.1.0
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testtools >= 2.2.0
Requires:       python-PyYAML >= 3.10
Requires:       python-cliff >= 2.8.0
Requires:       python-keystoneclient >= 3.8.0
Requires:       python-os-client-config >= 1.28.0
Requires:       python-osc-lib >= 1.8.0
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-osprofiler >= 1.4.0
Requires:       python-requests >= 2.14.2
Requires:       python-six >= 1.10.0
Requires:       python-stevedore >= 1.20.0
BuildArch:      noarch

%description
Client library for Mistral built on the Mistral API. It provides a Python API
(the mistralclient module) and a command-line tool (mistral).

%package doc
Summary:        Documentation for OpenStack Mistral API client libary
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme >= 1.18.1

%description doc
Client library for Mistral built on the Mistral API. It provides a Python API
(the mistralclient module) and a command-line tool (mistral).
This package contains the documentation.

%prep
%autosetup -p1 -n %{name}-%{version}
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%py2_build

# Build HTML docs and man page
%{__python2} setup.py build_sphinx -b man
rm -rf html/.{doctrees,buildinfo}

%install
%py2_install
#man pages
install -p -D -m 644 doc/build/man/mistral_client.1 %{buildroot}%{_mandir}/man1/mistral_client.1

%check
find . -type f -name *.pyc -delete
PYTHONPATH=. nosetests mistralclient/tests/unit

%files
%license LICENSE
%{python2_sitelib}/mistralclient
%{python2_sitelib}/*.egg-info
%{_bindir}/mistral
%{_mandir}/man1/mistral_client.1.*

%files doc
%license LICENSE

%changelog
* Fri Feb 23 2018 cloud-devel@suse.de
- update to version 3.3.0
  - Create and run a workflow within a namespace
  - Support for Project_domain_id and user_domain_id.
  - Update .gitreview for stable/queens
  - Avoid tox_install.sh for constraints support
  - Clean up keystone authentication
  - Use keystoneauth plugins and session instead of keystoneclient
  - Fix limit handling to not send value of -1
  - Namespaces release note
  - Fix how "--limit" is passed to the server for action executions
  - mistral execution-list -f value should be empty
  - Support no_auth mode in mistral client
  - Running new workflow based on existing execution.
  - Fix several problems in keycloak auth module
  - Remove "insecure" in token-based authentication.
  - Update and optimize documentation links
  - Update UPPER_CONSTRAINTS_FILE for stable/queens
  - Make README better
  - Task list now only queries the displayed fields.
  - Don't create client for help and bash completion
  - Add default values for domain related options
  - Don't override session during auth
  - Fix a typo in env variable name
  - Add test for target parameters and fix requests lib error
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Add CLI for event trigger operations
  - Enable ssl support for keycloak auth module
  - Updated from global requirements
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.1.4
  - Don't create client for help and bash completion
  - Fix several problems in keycloak auth module
  - Updated from global requirements
* Thu Sep 21 2017 cloud-devel@suse.de
- update to version 3.1.3
  - Fix how "--limit" is passed to the server for action executions
  - Update .gitreview for stable/pike
  - Enable ssl support for keycloak auth module
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.1.1
  - Remove white space between print () in cliutils.py and lintstack.py
  - Explicitly set 'builders' option
  - Add project_id and project_name options
  - Add release note for region name bugfix
  - Use oslotest instead of testtools/unittest
  - Initial commit for python-mistralclient document
  - Show team and repo badges on README
  - Fixing auth for keystone v2.0
  - Abstract authentication function
  - Add --utc flag to cron trigger create
  - Added sphinix config to setup.cfg
  - Add plug-in summary for osc doc
  - Take DST into account when converting to UTC
  - Trivial: Remove vim header from source files
  - Maintain releasenotes for python-mistralclient
  - Format the list of auth types in the Mistral client help
  - fix release note formatting
  - Enable DeprecationWarning in test environments
  - Fix for failing dsvm gate
  - Updated from global requirements
  - Expose the --run-sync Action Execution parameter on the CLI
  - Pass httpclient to managers
  - Enable some off-by-default checks
  - Send access info to server
  - String interpolation should be delayed
  - Update reno for stable/ocata
  - Accept keystone session in client
  - Region name related command line arguments are added
  - Fix wrong error message for environment operation
  - Give better tox output
  - Set the default value of --limit parameter
  - Removes unnecessary utf-8 encoding
  - Optimize the link address
  - Remove unused openstack/common/apiclient/client
  - Replace request mocking in test_httpclient with requests-mock
  - Update the gitingore
  - Remove commented-out Apache 2 classifier from setup.cfg
  - Updated tox.ini to pick up requirements from upper constraints
  - Update .gitignore
  - Fix python35 job failures
  - Change service type to workflowv2
  - Add '--filter' parameter to list commands in CLI
  - Fixed errors while generating releasenotes
  - Add filters to client Python APIs
  - Use assertGreater() or assertLess()
  - Make --profile load from environment variables
  - Make osprofiler dependency really "soft"
  - Add a missing space to the help message for execution-create
  - Move json.loads() method to utils.py, and use "with" to deal with file objects
  - Fix doc generation for python 3
  - Add cancelled state to action executions
  - Fix doc build if git is absent
  - Pass target insecure flag to msitral service
  - Keystone v3 needs extra parameters
  - Removing deprecation warnings to pass py35
  - Fixing getting mistral_url from keystone catalog
  - Added the reno for stable/mitaka stable/newton and stable/liberty
  - Added the # -*- coding: utf-8 -*- to the conf.py
  - Fix warning when running tox -e docs
  - Replaced savanna word with mistralclient
  - Make python mistralclient readme better
  - Adding files to .gitignore
  - Add Python 3.5 classifier and venv
  - Fix PEP8 issues and incorrect version/release details
  - Add tests for filters in CLI list commands
  - Read project_id and project_name in env
  - Replace uuid4() with generate_uuid() from oslo_utils
  - Removed the extra space from tox.ini
  - Use generic keystone client instead of versioned
  - Remove log translations
  - Update test requirement
  - Changed the README.rst
  - Remove support for py34
  - Remove unused pylint
  - remove openstack/common/cliutils.py
  - Refactor common parts of client tests
  - Avoid use xx=[] for parameter to initialize it's value
  - Enable release notes translation
  - Add user and project domain name parameters for target cloud
  - Filter workflow executions by creating task execution id
  - Remove unused scripts in tools
  - Fix region support in mistralclient
  - Use requests-mock for testing
  - Enable warning-is-error in doc build
  - Switch from oslosphinx to openstackdocstheme
  - Cosmetic changes in CLI tests
  - remove apiclient from mistralclient
  - Added link for modindex
  - Add 'created_at' and 'updated_at' to action-execution-get and action-execution-list command
  - doc: Remove cruft from conf.py
  - Add 'created_at' and 'updated_at' to task-get command
  - Use session from OSC plugin
  - Remove clashes of openstackclient command in mistral
  - Initial commit for mistral-i18n support
  - Removed openstack/common/importutils.py
  - Apply Pike document structure
* Fri Jun 23 2017 tbechtold@suse.com
- Switch to Ocata in _service
- update requirements
* Thu Jan  5 2017 dmueller@suse.com
- update to 2.1.2:
  * Remove clashes of openstackclient command in mistral
  * Make osprofiler dependency really "soft"
  * Added sphinix config to setup.cfg
  * Expose the --run-sync Action Execution parameter on the CLI
  * Update .gitreview for stable/newton
* Thu Oct 13 2016 dmueller@suse.com
- sync with git
* Fri Sep 30 2016 dmueller@suse.com
- update to 2.1.1:
  * Updated from global requirements
  * Updated from global requirements
  * Added ID option to update Action Definition
  * Add error message when OS_USERNAME or OS_PASSWORD not provided
  * Add target-* parameters to python-mistralclient
  * Different formatters for "action-execution-get" and "action-execution-list"
  * Add "Task ID" field for "action-execution-get" command output
  * Remove usage of private '_url' property from OSC
  * Add cancelled state to executions
  * Added 'pip install -r requirements.txt' instruction
  * Updated from global requirements
  * Fixed ssl options for httpclient
  * Changed argument names as per other python clients
  * Change action-get help to get action info by ID
  * Updated from global requirements
  * Add KeyCloak OpenID Connect authentication
  * Updated from global requirements
  * Use osc_lib instead of cliff
  * Use osc-lib instead of openstackclient
  * Updated from global requirements
  * Removed use of tempest_lib and used tempest instead
  * Updated from global requirements
  * Remove .mailmap since it's no longer needed
  * Updated from global requirements
  * Add osprofiler option to trace operations                                                  +* Remove AUTHORS file from git tracking
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements                                                           +* Updated from global requirements
  * Added CONTRIBUTING.rst file
  * Validate ad-hoc action via cli
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Fix task result syntax in workflows used for functional tests
  * Updated from global requirements
  * Fix cacert and insecure options on HTTP requests
  * Change the mistralclient for Mistral action pack
* Mon Sep  5 2016 tbechtold@suse.com
- Initial packaging (version 2.0.0)
